#!/usr/bin/python
#
# Copyright 2014 Microsoft Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argparse
import azsec.util as util
import os
import string
import sys
import syslog
from azsec.util import waagent
from defusedxml.ElementTree import parse

# Initialize waagent
waagent.LoggerInit('/var/log/waagent.log','/dev/stdout')

# General Settings
configFile = util.defaultConfigFile
baselineScript = util.scriptDir + "/apply-secbaseline.sh"
   
# Parse command line arguments, set options as appropriate
def ParseArguments():
    global configFile
    parser = argparse.ArgumentParser(description='Enable/disable security scanning options [' + configFile + ']')
    parser.add_argument(
        '-v', '--verbose', help='Write output to stdout', action='count')
    parser.add_argument(
        '-l', '--list', help='List scans along with their status (enabled/disabled)', action='store_true')
    parser.add_argument(
        '-b', '--baselinescan', help='Enable or disable  baseline configuration scan')
    parser.add_argument(
        '-f', '--file', help='use the specified config file')
    parser.add_argument(
        '-p', '--patchscan', help='Enable or disable patch scan')
    parser.add_argument(
        '-s', '--softwarescan', help='Enable or disable  software inventory scan')
    parser.add_argument(
        '-ab', '--applybaseline', help='*Applies secure baseline settings to system*', action='store_true')
    args = parser.parse_args()
    # Set verbosity level for writing to console
    if args.verbose:
        util.runtimeVerbosity = args.verbose
    if args.file:
        configFile=args.file
    return args

def ApplyBaseline():
    print "**WARNING - This will script will make changes to your system! **"
    print "For additional details visit: http://aka.ms/jrt4vl"
    response = raw_input("Are you sure you want to proceed?[YES/NO]")
    if not (response == "YES"):
        util.WriteConsole(syslog.LOG_INFO,"Installation of secure baseline was cancelled by user input")
        return 0
    util.WriteConsole(syslog.LOG_INFO,"Initiating installation of secure baseline")
    error,msg = waagent.RunGetOutput(baselineScript)
    lines = string.split(msg, "\n")
    for line in lines:
        util.WriteLog(syslog.LOG_INFO, line)
    logpri = syslog.LOG_WARNING if error else syslog.LOG_INFO
    util.WriteConsole(logpri,"Installation of secure baseline is complete [{0}]".format(error))
    return 0

# Parse arguments and config file, kick off scans, report results
def main():
    args = ParseArguments()
    exitCode = 0
    if (args.applybaseline):
        exitCode += ApplyBaseline()
    exitCode += util.ModifyConfigs(args, configFile)
    if args.list:
        util.WriteDebug("Processing 'list' command")
        success, elementTree = util.GetXmlFileElementTree(configFile)
        if not success:
            return 1
        config = elementTree.getroot()
        scanners = config.find('scanners')
        for key in scanners.keys():
            print "{0:<17s} {1}".format(key, scanners.get(key))
    sys.exit(exitCode)

main()

